@@ -1,7 +1,7 @@
 #! /bin/sh
 
 # Build some of the Autoconf test files.
-# Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
+# Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -144,7 +144,7 @@ ac_exclude_list='^AC_ARG_VAR$
 ^(AC_TRY.*|AC_RUN_LOG)$
 ^AC_.*_IFELSE$
 ^AC_FD_CC$
-^(AC_(PROG_CC|C_CONST|C_INLINE|C_VOLATILE))$
+^(AC_(PROG_CC|C_CONST|C_INLINE|C_RESTRICT|C_VOLATILE))$
 ^AC_(CYGWIN|CYGWIN32|EMXOS2|MING32|EXEEXT|OBJEXT)$
 ^AC_PATH_XTRA$
 ^AC_SYS_RESTARTABLE_SYSCALLS$
@@ -155,10 +155,7 @@ _AC_'
 # ac_exclude_egrep
 # ----------------
 # Build a single extended regular expression out of filter_macros_list.
-# Sed is used to get rid of the trailing `|' coming from the trailing
-# `\n' from `echo'.
-ac_exclude_egrep=`echo "$exclude_list$ac_exclude_list" | tr '
-' '|' | sed 's/.$//'`
+ac_exclude_egrep=$exclude_list$ac_exclude_list
 
 
 # au_exclude_list
@@ -183,10 +180,7 @@ au_exclude_list='^AC_LANG_RESTORE$
 # au_exclude_egrep
 # ----------------
 # Build a single extended regular expression out of filter_macros_list.
-# Sed is used to get rid of the trailing `|' coming from the trailing
-# `\n' from `echo'.
-au_exclude_egrep=`echo "$exclude_list$au_exclude_list" | tr '
-' '|' | sed 's/.$//'`
+au_exclude_egrep=$exclude_list$au_exclude_list
 
 
 # egrep
